# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

<!-- insertion marker -->
## [v1.0.1](https://github.com/velez94/reverse_diagrams/releases/tag/v1.0.1) - 2024-01-29

<small>[Compare with v1.0.0](https://github.com/velez94/reverse_diagrams/compare/v1.0.0...v1.0.1)</small>

### Code Refactoring

- refactor getting account assignments ([42f29cd](https://github.com/velez94/reverse_diagrams/commit/42f29cd131f356b871b2c2aed8f7a996ed114435) by alejandro.velez).

### Docs

- add changelog ([f57076c](https://github.com/velez94/reverse_diagrams/commit/f57076c0f8cf9cbdc9b2a286c6ef3ee553dc3818) by alejandro.velez).

## [v1.0.0](https://github.com/velez94/reverse_diagrams/releases/tag/v1.0.0) - 2024-01-29

<small>[Compare with v0.2.5](https://github.com/velez94/reverse_diagrams/compare/v0.2.5...v1.0.0)</small>

### Features

- v1.0.0 release beta ([8c2fcb2](https://github.com/velez94/reverse_diagrams/commit/8c2fcb253fc0bc4b5dbfdf292979d9fd63c3393f) by alejandro.velez).
- update license ([e6446f0](https://github.com/velez94/reverse_diagrams/commit/e6446f059cbfd52708f4f3fa5b0bbc33d7af5dae) by alejandro.velez).
- add workflow ([4800e02](https://github.com/velez94/reverse_diagrams/commit/4800e0215336b6e3d54be7dbc6f72b5608ed2847) by alejandro.velez).
- add pagination option to get group members ([79f26e7](https://github.com/velez94/reverse_diagrams/commit/79f26e7729655e2c0acc220d1daaa909b47e2b24) by wilmar.velezl).

## [v0.2.5](https://github.com/velez94/reverse_diagrams/releases/tag/v0.2.5) - 2023-01-30

<small>[Compare with v0.2.3](https://github.com/velez94/reverse_diagrams/compare/v0.2.3...v0.2.5)</small>

## [v0.2.3](https://github.com/velez94/reverse_diagrams/releases/tag/v0.2.3) - 2023-01-30

<small>[Compare with first commit](https://github.com/velez94/reverse_diagrams/compare/9ee05c383bf95a8f575e794e08b52672ad7c16cb...v0.2.3)</small>

